package FBP::Control;

use Mouse::Role;

our $VERSION = '0.05';

has default => (
	is  => 'ro',
	isa => 'Bool',
);

1;
